@@ -3,6 +3,7 @@ from unittest import mock
 import responses  # type: ignore
 import json
 import gzip
+import os
 from tests.cli_test_case import CliTestCase
 
 
@@ -11,6 +12,7 @@ class BehaveTest(CliTestCase):
         '../data/behave/').resolve()
 
     @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_subset(self):
         pipe = "tutorial.feature"
         result = self.cli('subset', '--target', '10%', '--session',
@@ -25,14 +27,14 @@ class BehaveTest(CliTestCase):
 
         self.assert_json_orderless_equal(expected, payload)
 
-    @ responses.activate
+    @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_record_test(self):
         result = self.cli('record', 'tests',  '--session', self.session,
                           'behave', str(self.test_files_dir) + "/reports/report.xml")
         self.assertEqual(result.exit_code, 0)
 
-        payload = json.loads(gzip.decompress(
-            b''.join(responses.calls[1].request.body)).decode())
+        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
 
         for e in payload["events"]:
             del e["created_at"]
